@@ -73,7 +73,7 @@ def test_create_table_with_database_location(
     test_catalog = DynamoDbCatalog(catalog_name, **{"s3.endpoint": moto_endpoint_url})
     test_catalog.create_namespace(namespace=database_name, properties={"location": f"s3://{BUCKET_NAME}/{database_name}.db"})
     table = test_catalog.create_table(identifier, table_schema_nested)
-    assert table.identifier == (catalog_name,) + identifier
+    assert table.name() == identifier
     assert TABLE_METADATA_LOCATION_REGEX.match(table.metadata_location)
 
 
@@ -90,7 +90,7 @@ def test_create_table_with_pyarrow_schema(
     test_catalog = DynamoDbCatalog(catalog_name, **{"s3.endpoint": moto_endpoint_url})
     test_catalog.create_namespace(namespace=database_name, properties={"location": f"s3://{BUCKET_NAME}/{database_name}.db"})
     table = test_catalog.create_table(identifier, pyarrow_schema_simple_without_ids)
-    assert table.identifier == (catalog_name,) + identifier
+    assert table.name() == identifier
     assert TABLE_METADATA_LOCATION_REGEX.match(table.metadata_location)
 
 
@@ -103,7 +103,7 @@ def test_create_table_with_default_warehouse(
     test_catalog = DynamoDbCatalog(catalog_name, **{"s3.endpoint": moto_endpoint_url, "warehouse": f"s3://{BUCKET_NAME}"})
     test_catalog.create_namespace(namespace=database_name)
     table = test_catalog.create_table(identifier, table_schema_nested)
-    assert table.identifier == (catalog_name,) + identifier
+    assert table.name() == identifier
     assert TABLE_METADATA_LOCATION_REGEX.match(table.metadata_location)
 
 
@@ -118,7 +118,7 @@ def test_create_table_with_given_location(
     table = test_catalog.create_table(
         identifier=identifier, schema=table_schema_nested, location=f"s3://{BUCKET_NAME}/{database_name}.db/{table_name}"
     )
-    assert table.identifier == (catalog_name,) + identifier
+    assert table.name() == identifier
     assert TABLE_METADATA_LOCATION_REGEX.match(table.metadata_location)
 
 
@@ -132,7 +132,7 @@ def test_create_table_removes_trailing_slash_in_location(
     test_catalog.create_namespace(namespace=database_name)
     location = f"s3://{BUCKET_NAME}/{database_name}.db/{table_name}"
     table = test_catalog.create_table(identifier=identifier, schema=table_schema_nested, location=f"{location}/")
-    assert table.identifier == (catalog_name,) + identifier
+    assert table.name() == identifier
     assert table.location() == location
     assert TABLE_METADATA_LOCATION_REGEX.match(table.metadata_location)
 
@@ -157,7 +157,7 @@ def test_create_table_with_strips(
     test_catalog = DynamoDbCatalog(catalog_name, **{"s3.endpoint": moto_endpoint_url})
     test_catalog.create_namespace(namespace=database_name, properties={"location": f"s3://{BUCKET_NAME}/{database_name}.db/"})
     table = test_catalog.create_table(identifier, table_schema_nested)
-    assert table.identifier == (catalog_name,) + identifier
+    assert table.name() == identifier
     assert TABLE_METADATA_LOCATION_REGEX.match(table.metadata_location)
 
 
@@ -170,7 +170,7 @@ def test_create_table_with_strips_bucket_root(
     test_catalog = DynamoDbCatalog(catalog_name, **{"s3.endpoint": moto_endpoint_url, "warehouse": f"s3://{BUCKET_NAME}/"})
     test_catalog.create_namespace(namespace=database_name)
     table_strip = test_catalog.create_table(identifier, table_schema_nested)
-    assert table_strip.identifier == (catalog_name,) + identifier
+    assert table_strip.name() == identifier
     assert TABLE_METADATA_LOCATION_REGEX.match(table_strip.metadata_location)
 
 
@@ -205,7 +205,7 @@ def test_create_table_if_not_exists_duplicated_table(
     test_catalog.create_namespace(namespace=database_name)
     table1 = test_catalog.create_table(identifier, table_schema_nested)
     table2 = test_catalog.create_table_if_not_exists(identifier, table_schema_nested)
-    assert table1.identifier == table2.identifier
+    assert table1.name() == table2.name()
 
 
 @mock_aws
@@ -218,7 +218,7 @@ def test_load_table(
     test_catalog.create_namespace(namespace=database_name)
     test_catalog.create_table(identifier, table_schema_nested)
     table = test_catalog.load_table(identifier)
-    assert table.identifier == (catalog_name,) + identifier
+    assert table.name() == identifier
     assert TABLE_METADATA_LOCATION_REGEX.match(table.metadata_location)
 
 
@@ -232,8 +232,8 @@ def test_load_table_from_self_identifier(
     test_catalog.create_namespace(namespace=database_name)
     test_catalog.create_table(identifier, table_schema_nested)
     intermediate = test_catalog.load_table(identifier)
-    table = test_catalog.load_table(intermediate.identifier)
-    assert table.identifier == (catalog_name,) + identifier
+    table = test_catalog.load_table(intermediate.name())
+    assert table.name() == identifier
     assert TABLE_METADATA_LOCATION_REGEX.match(table.metadata_location)
 
 
@@ -256,7 +256,7 @@ def test_drop_table(
     test_catalog.create_namespace(namespace=database_name)
     test_catalog.create_table(identifier, table_schema_nested)
     table = test_catalog.load_table(identifier)
-    assert table.identifier == (catalog_name,) + identifier
+    assert table.name() == identifier
     assert TABLE_METADATA_LOCATION_REGEX.match(table.metadata_location)
     test_catalog.drop_table(identifier)
     with pytest.raises(NoSuchTableError):
@@ -273,13 +273,13 @@ def test_drop_table_from_self_identifier(
     test_catalog.create_namespace(namespace=database_name)
     test_catalog.create_table(identifier, table_schema_nested)
     table = test_catalog.load_table(identifier)
-    assert table.identifier == (catalog_name,) + identifier
+    assert table.name() == identifier
     assert TABLE_METADATA_LOCATION_REGEX.match(table.metadata_location)
-    test_catalog.drop_table(table.identifier)
+    test_catalog.drop_table(table.name())
     with pytest.raises(NoSuchTableError):
         test_catalog.load_table(identifier)
     with pytest.raises(NoSuchTableError):
-        test_catalog.load_table(table.identifier)
+        test_catalog.load_table(table.name())
 
 
 @mock_aws
@@ -301,11 +301,11 @@ def test_rename_table(
     test_catalog = DynamoDbCatalog(catalog_name, **{"warehouse": f"s3://{BUCKET_NAME}", "s3.endpoint": moto_endpoint_url})
     test_catalog.create_namespace(namespace=database_name)
     table = test_catalog.create_table(identifier, table_schema_nested)
-    assert table.identifier == (catalog_name,) + identifier
+    assert table.name() == identifier
     assert TABLE_METADATA_LOCATION_REGEX.match(table.metadata_location)
     test_catalog.rename_table(identifier, new_identifier)
     new_table = test_catalog.load_table(new_identifier)
-    assert new_table.identifier == (catalog_name,) + new_identifier
+    assert new_table.name() == new_identifier
     # the metadata_location should not change
     assert new_table.metadata_location == table.metadata_location
     # old table should be dropped
@@ -324,18 +324,18 @@ def test_rename_table_from_self_identifier(
     test_catalog = DynamoDbCatalog(catalog_name, **{"warehouse": f"s3://{BUCKET_NAME}", "s3.endpoint": moto_endpoint_url})
     test_catalog.create_namespace(namespace=database_name)
     table = test_catalog.create_table(identifier, table_schema_nested)
-    assert table.identifier == (catalog_name,) + identifier
+    assert table.name() == identifier
     assert TABLE_METADATA_LOCATION_REGEX.match(table.metadata_location)
-    test_catalog.rename_table(table.identifier, new_identifier)
+    test_catalog.rename_table(table.name(), new_identifier)
     new_table = test_catalog.load_table(new_identifier)
-    assert new_table.identifier == (catalog_name,) + new_identifier
+    assert new_table.name() == new_identifier
     # the metadata_location should not change
     assert new_table.metadata_location == table.metadata_location
     # old table should be dropped
     with pytest.raises(NoSuchTableError):
         test_catalog.load_table(identifier)
     with pytest.raises(NoSuchTableError):
-        test_catalog.load_table(table.identifier)
+        test_catalog.load_table(table.name())
 
 
 @mock_aws
