@@ -290,70 +290,70 @@ def test_fsspec_unified_session_properties() -> None:
         )
 
 
-@pytest.mark.adlfs
-def test_fsspec_new_input_file_adlfs(adlfs_fsspec_fileio: FsspecFileIO) -> None:
+@pytest.mark.adls
+def test_fsspec_new_input_file_adls(adls_fsspec_fileio: FsspecFileIO) -> None:
     """Test creating a new input file from an fsspec file-io"""
     filename = str(uuid.uuid4())
 
-    input_file = adlfs_fsspec_fileio.new_input(f"abfss://tests/{filename}")
+    input_file = adls_fsspec_fileio.new_input(f"abfss://tests/{filename}")
 
     assert isinstance(input_file, fsspec.FsspecInputFile)
     assert input_file.location == f"abfss://tests/{filename}"
 
 
-@pytest.mark.adlfs
-def test_fsspec_new_abfss_output_file_adlfs(adlfs_fsspec_fileio: FsspecFileIO) -> None:
+@pytest.mark.adls
+def test_fsspec_new_abfss_output_file_adls(adls_fsspec_fileio: FsspecFileIO) -> None:
     """Test creating a new output file from an fsspec file-io"""
     filename = str(uuid.uuid4())
 
-    output_file = adlfs_fsspec_fileio.new_output(f"abfss://tests/{filename}")
+    output_file = adls_fsspec_fileio.new_output(f"abfss://tests/{filename}")
 
     assert isinstance(output_file, fsspec.FsspecOutputFile)
     assert output_file.location == f"abfss://tests/{filename}"
 
 
-@pytest.mark.adlfs
-def test_fsspec_write_and_read_file_adlfs(adlfs_fsspec_fileio: FsspecFileIO) -> None:
+@pytest.mark.adls
+def test_fsspec_write_and_read_file_adls(adls_fsspec_fileio: FsspecFileIO) -> None:
     """Test writing and reading a file using FsspecInputFile and FsspecOutputFile"""
     filename = str(uuid.uuid4())
-    output_file = adlfs_fsspec_fileio.new_output(location=f"abfss://tests/{filename}")
+    output_file = adls_fsspec_fileio.new_output(location=f"abfss://tests/{filename}")
     with output_file.create() as f:
         f.write(b"foo")
 
-    input_file = adlfs_fsspec_fileio.new_input(f"abfss://tests/{filename}")
+    input_file = adls_fsspec_fileio.new_input(f"abfss://tests/{filename}")
     assert input_file.open().read() == b"foo"
 
-    adlfs_fsspec_fileio.delete(input_file)
+    adls_fsspec_fileio.delete(input_file)
 
 
-@pytest.mark.adlfs
-def test_fsspec_getting_length_of_file_adlfs(adlfs_fsspec_fileio: FsspecFileIO) -> None:
+@pytest.mark.adls
+def test_fsspec_getting_length_of_file_adls(adls_fsspec_fileio: FsspecFileIO) -> None:
     """Test getting the length of an FsspecInputFile and FsspecOutputFile"""
     filename = str(uuid.uuid4())
 
-    output_file = adlfs_fsspec_fileio.new_output(location=f"abfss://tests/{filename}")
+    output_file = adls_fsspec_fileio.new_output(location=f"abfss://tests/{filename}")
     with output_file.create() as f:
         f.write(b"foobar")
 
     assert len(output_file) == 6
 
-    input_file = adlfs_fsspec_fileio.new_input(location=f"abfss://tests/{filename}")
+    input_file = adls_fsspec_fileio.new_input(location=f"abfss://tests/{filename}")
     assert len(input_file) == 6
 
-    adlfs_fsspec_fileio.delete(output_file)
+    adls_fsspec_fileio.delete(output_file)
 
 
-@pytest.mark.adlfs
-def test_fsspec_file_tell_adlfs(adlfs_fsspec_fileio: FsspecFileIO) -> None:
+@pytest.mark.adls
+def test_fsspec_file_tell_adls(adls_fsspec_fileio: FsspecFileIO) -> None:
     """Test finding cursor position for an fsspec file-io file"""
 
     filename = str(uuid.uuid4())
 
-    output_file = adlfs_fsspec_fileio.new_output(location=f"abfss://tests/{filename}")
+    output_file = adls_fsspec_fileio.new_output(location=f"abfss://tests/{filename}")
     with output_file.create() as write_file:
         write_file.write(b"foobar")
 
-    input_file = adlfs_fsspec_fileio.new_input(location=f"abfss://tests/{filename}")
+    input_file = adls_fsspec_fileio.new_input(location=f"abfss://tests/{filename}")
     f = input_file.open()
 
     f.seek(0)
@@ -365,19 +365,19 @@ def test_fsspec_file_tell_adlfs(adlfs_fsspec_fileio: FsspecFileIO) -> None:
     f.seek(0)
     assert f.tell() == 0
 
-    adlfs_fsspec_fileio.delete(f"abfss://tests/{filename}")
+    adls_fsspec_fileio.delete(f"abfss://tests/{filename}")
 
 
-@pytest.mark.adlfs
-def test_fsspec_read_specified_bytes_for_file_adlfs(adlfs_fsspec_fileio: FsspecFileIO) -> None:
+@pytest.mark.adls
+def test_fsspec_read_specified_bytes_for_file_adls(adls_fsspec_fileio: FsspecFileIO) -> None:
     """Test reading a specified number of bytes from an fsspec file-io file"""
 
     filename = str(uuid.uuid4())
-    output_file = adlfs_fsspec_fileio.new_output(location=f"abfss://tests/{filename}")
+    output_file = adls_fsspec_fileio.new_output(location=f"abfss://tests/{filename}")
     with output_file.create() as write_file:
         write_file.write(b"foo")
 
-    input_file = adlfs_fsspec_fileio.new_input(location=f"abfss://tests/{filename}")
+    input_file = adls_fsspec_fileio.new_input(location=f"abfss://tests/{filename}")
     f = input_file.open()
 
     f.seek(0)
@@ -391,89 +391,89 @@ def test_fsspec_read_specified_bytes_for_file_adlfs(adlfs_fsspec_fileio: FsspecF
     f.seek(0)
     assert b"foo" == f.read(999)  # test reading amount larger than entire content length
 
-    adlfs_fsspec_fileio.delete(input_file)
+    adls_fsspec_fileio.delete(input_file)
 
 
-@pytest.mark.adlfs
-def test_fsspec_raise_on_opening_file_not_found_adlfs(adlfs_fsspec_fileio: FsspecFileIO) -> None:
-    """Test that an fsspec input file raises appropriately when the adlfs file is not found"""
+@pytest.mark.adls
+def test_fsspec_raise_on_opening_file_not_found_adls(adls_fsspec_fileio: FsspecFileIO) -> None:
+    """Test that an fsspec input file raises appropriately when the adls file is not found"""
 
     filename = str(uuid.uuid4())
-    input_file = adlfs_fsspec_fileio.new_input(location=f"abfss://tests/{filename}")
+    input_file = adls_fsspec_fileio.new_input(location=f"abfss://tests/{filename}")
     with pytest.raises(FileNotFoundError) as exc_info:
         input_file.open().read()
 
     assert filename in str(exc_info.value)
 
 
-@pytest.mark.adlfs
-def test_checking_if_a_file_exists_adlfs(adlfs_fsspec_fileio: FsspecFileIO) -> None:
+@pytest.mark.adls
+def test_checking_if_a_file_exists_adls(adls_fsspec_fileio: FsspecFileIO) -> None:
     """Test checking if a file exists"""
 
-    non_existent_file = adlfs_fsspec_fileio.new_input(location="abfss://tests/does-not-exist.txt")
+    non_existent_file = adls_fsspec_fileio.new_input(location="abfss://tests/does-not-exist.txt")
     assert not non_existent_file.exists()
 
     filename = str(uuid.uuid4())
-    output_file = adlfs_fsspec_fileio.new_output(location=f"abfss://tests/{filename}")
+    output_file = adls_fsspec_fileio.new_output(location=f"abfss://tests/{filename}")
     assert not output_file.exists()
     with output_file.create() as f:
         f.write(b"foo")
 
-    existing_input_file = adlfs_fsspec_fileio.new_input(location=f"abfss://tests/{filename}")
+    existing_input_file = adls_fsspec_fileio.new_input(location=f"abfss://tests/{filename}")
     assert existing_input_file.exists()
 
-    existing_output_file = adlfs_fsspec_fileio.new_output(location=f"abfss://tests/{filename}")
+    existing_output_file = adls_fsspec_fileio.new_output(location=f"abfss://tests/{filename}")
     assert existing_output_file.exists()
 
-    adlfs_fsspec_fileio.delete(existing_output_file)
+    adls_fsspec_fileio.delete(existing_output_file)
 
 
-@pytest.mark.adlfs
-def test_closing_a_file_adlfs(adlfs_fsspec_fileio: FsspecFileIO) -> None:
+@pytest.mark.adls
+def test_closing_a_file_adls(adls_fsspec_fileio: FsspecFileIO) -> None:
     """Test closing an output file and input file"""
     filename = str(uuid.uuid4())
-    output_file = adlfs_fsspec_fileio.new_output(location=f"abfss://tests/{filename}")
+    output_file = adls_fsspec_fileio.new_output(location=f"abfss://tests/{filename}")
     with output_file.create() as write_file:
         write_file.write(b"foo")
         assert not write_file.closed  # type: ignore
     assert write_file.closed  # type: ignore
 
-    input_file = adlfs_fsspec_fileio.new_input(location=f"abfss://tests/{filename}")
+    input_file = adls_fsspec_fileio.new_input(location=f"abfss://tests/{filename}")
     f = input_file.open()
     assert not f.closed  # type: ignore
     f.close()
     assert f.closed  # type: ignore
 
-    adlfs_fsspec_fileio.delete(f"abfss://tests/{filename}")
+    adls_fsspec_fileio.delete(f"abfss://tests/{filename}")
 
 
-@pytest.mark.adlfs
-def test_fsspec_converting_an_outputfile_to_an_inputfile_adlfs(adlfs_fsspec_fileio: FsspecFileIO) -> None:
+@pytest.mark.adls
+def test_fsspec_converting_an_outputfile_to_an_inputfile_adls(adls_fsspec_fileio: FsspecFileIO) -> None:
     """Test converting an output file to an input file"""
     filename = str(uuid.uuid4())
-    output_file = adlfs_fsspec_fileio.new_output(location=f"abfss://tests/{filename}")
+    output_file = adls_fsspec_fileio.new_output(location=f"abfss://tests/{filename}")
     input_file = output_file.to_input_file()
     assert input_file.location == output_file.location
 
 
-@pytest.mark.adlfs
-def test_writing_avro_file_adlfs(generated_manifest_entry_file: str, adlfs_fsspec_fileio: FsspecFileIO) -> None:
+@pytest.mark.adls
+def test_writing_avro_file_adls(generated_manifest_entry_file: str, adls_fsspec_fileio: FsspecFileIO) -> None:
     """Test that bytes match when reading a local avro file, writing it using fsspec file-io, and then reading it again"""
     filename = str(uuid.uuid4())
     with PyArrowFileIO().new_input(location=generated_manifest_entry_file).open() as f:
         b1 = f.read()
-        with adlfs_fsspec_fileio.new_output(location=f"abfss://tests/{filename}").create() as out_f:
+        with adls_fsspec_fileio.new_output(location=f"abfss://tests/{filename}").create() as out_f:
             out_f.write(b1)
-        with adlfs_fsspec_fileio.new_input(location=f"abfss://tests/{filename}").open() as in_f:
+        with adls_fsspec_fileio.new_input(location=f"abfss://tests/{filename}").open() as in_f:
             b2 = in_f.read()
-            assert b1 == b2  # Check that bytes of read from local avro file match bytes written to adlfs
+            assert b1 == b2  # Check that bytes of read from local avro file match bytes written to adls
 
-    adlfs_fsspec_fileio.delete(f"abfss://tests/{filename}")
+    adls_fsspec_fileio.delete(f"abfss://tests/{filename}")
 
 
-@pytest.mark.adlfs
-def test_fsspec_pickle_round_trip_aldfs(adlfs_fsspec_fileio: FsspecFileIO) -> None:
-    _test_fsspec_pickle_round_trip(adlfs_fsspec_fileio, "abfss://tests/foo.txt")
+@pytest.mark.adls
+def test_fsspec_pickle_round_trip_aldfs(adls_fsspec_fileio: FsspecFileIO) -> None:
+    _test_fsspec_pickle_round_trip(adls_fsspec_fileio, "abfss://tests/foo.txt")
 
 
 @pytest.mark.gcs
@@ -727,6 +727,59 @@ def test_s3v4_rest_signer(requests_mock: Mocker) -> None:
     }
 
 
+def test_s3v4_rest_signer_endpoint(requests_mock: Mocker) -> None:
+    new_uri = "https://other-bucket/metadata/snap-8048355899640248710-1-a5c8ea2d-aa1f-48e8-89f4-1fa69db8c742.avro"
+    endpoint = "v1/main/s3-sign/foo.bar?e=e&b=b&k=k=k&s=s&w=w"
+    requests_mock.post(
+        f"{TEST_URI}/{endpoint}",
+        json={
+            "uri": new_uri,
+            "headers": {
+                "Authorization": [
+                    "AWS4-HMAC-SHA256 Credential=ASIAQPRZZYGHUT57DL3I/20221017/us-west-2/s3/aws4_request, SignedHeaders=host;x-amz-content-sha256;x-amz-date;x-amz-security-token, Signature=430582a17d61ab02c272896fa59195f277af4bdf2121c441685e589f044bbe02"
+                ],
+                "Host": ["bucket.s3.us-west-2.amazonaws.com"],
+                "User-Agent": ["Botocore/1.27.59 Python/3.10.7 Darwin/21.5.0"],
+                "x-amz-content-sha256": ["UNSIGNED-PAYLOAD"],
+                "X-Amz-Date": ["20221017T102940Z"],
+                "X-Amz-Security-Token": [
+                    "YQoJb3JpZ2luX2VjEDoaCXVzLXdlc3QtMiJGMEQCID/fFxZP5oaEgQmcwP6XhZa0xSq9lmLSx8ffaWbySfUPAiAesa7sjd/WV4uwRTO0S03y/MWVtgpH+/NyZQ4bZgLVriqrAggTEAEaDDAzMzQwNzIyMjE1OSIMOeFOWhZIurMmAqjsKogCxMCqxX8ZjK0gacAkcDqBCyA7qTSLhdfKQIH/w7WpLBU1km+cRUWWCudan6gZsAq867DBaKEP7qI05DAWr9MChAkgUgyI8/G3Z23ET0gAedf3GsJbakB0F1kklx8jPmj4BPCht9RcTiXiJ5DxTS/cRCcalIQXmPFbaJSqpBusVG2EkWnm1v7VQrNPE2Os2b2P293vpbhwkyCEQiGRVva4Sw9D1sKvqSsK10QCRG+os6dFEOu1kARaXi6pStvR4OVmj7OYeAYjzaFchn7nz2CSae0M4IluiYQ01eQAywbfRo9DpKSmDM/DnPZWJnD/woLhaaaCrCxSSEaFsvGOHFhLd3Rknw1v0jADMILUtJoGOp4BpqKqyMz0CY3kpKL0jfR3ykTf/ge9wWVE0Alr7wRIkGCIURkhslGHqSyFRGoTqIXaxU+oPbwlw/0w/nYO7qQ6bTANOWye/wgw4h/NmJ6vU7wnZTXwREf1r6MF72++bE/fMk19LfVb8jN/qrUqAUXTc8gBAUxL5pgy8+oT/JnI2BkVrrLS4ilxEXP9Ahm+6GDUYXV4fBpqpZwdkzQ/5Gw="
+                ],
+            },
+            "extensions": {},
+        },
+        status_code=200,
+    )
+
+    request = AWSRequest(
+        method="HEAD",
+        url="https://bucket/metadata/snap-8048355899640248710-1-a5c8ea2d-aa1f-48e8-89f4-1fa69db8c742.avro",
+        headers={"User-Agent": "Botocore/1.27.59 Python/3.10.7 Darwin/21.5.0"},
+        data=b"",
+        params={},
+        auth_path="/metadata/snap-8048355899640248710-1-a5c8ea2d-aa1f-48e8-89f4-1fa69db8c742.avro",
+    )
+    request.context = {
+        "client_region": "us-west-2",
+        "has_streaming_input": False,
+        "auth_type": None,
+        "signing": {"bucket": "bucket"},
+        "retries": {"attempt": 1, "invocation-id": "75d143fb-0219-439b-872c-18213d1c8d54"},
+    }
+
+    signed_request = s3v4_rest_signer({"token": "abc", "uri": TEST_URI, "s3.signer.endpoint": endpoint}, request)
+
+    assert signed_request.url == new_uri
+    assert dict(signed_request.headers) == {
+        "Authorization": "AWS4-HMAC-SHA256 Credential=ASIAQPRZZYGHUT57DL3I/20221017/us-west-2/s3/aws4_request, SignedHeaders=host;x-amz-content-sha256;x-amz-date;x-amz-security-token, Signature=430582a17d61ab02c272896fa59195f277af4bdf2121c441685e589f044bbe02",
+        "Host": "bucket.s3.us-west-2.amazonaws.com",
+        "User-Agent": "Botocore/1.27.59 Python/3.10.7 Darwin/21.5.0",
+        "X-Amz-Date": "20221017T102940Z",
+        "X-Amz-Security-Token": "YQoJb3JpZ2luX2VjEDoaCXVzLXdlc3QtMiJGMEQCID/fFxZP5oaEgQmcwP6XhZa0xSq9lmLSx8ffaWbySfUPAiAesa7sjd/WV4uwRTO0S03y/MWVtgpH+/NyZQ4bZgLVriqrAggTEAEaDDAzMzQwNzIyMjE1OSIMOeFOWhZIurMmAqjsKogCxMCqxX8ZjK0gacAkcDqBCyA7qTSLhdfKQIH/w7WpLBU1km+cRUWWCudan6gZsAq867DBaKEP7qI05DAWr9MChAkgUgyI8/G3Z23ET0gAedf3GsJbakB0F1kklx8jPmj4BPCht9RcTiXiJ5DxTS/cRCcalIQXmPFbaJSqpBusVG2EkWnm1v7VQrNPE2Os2b2P293vpbhwkyCEQiGRVva4Sw9D1sKvqSsK10QCRG+os6dFEOu1kARaXi6pStvR4OVmj7OYeAYjzaFchn7nz2CSae0M4IluiYQ01eQAywbfRo9DpKSmDM/DnPZWJnD/woLhaaaCrCxSSEaFsvGOHFhLd3Rknw1v0jADMILUtJoGOp4BpqKqyMz0CY3kpKL0jfR3ykTf/ge9wWVE0Alr7wRIkGCIURkhslGHqSyFRGoTqIXaxU+oPbwlw/0w/nYO7qQ6bTANOWye/wgw4h/NmJ6vU7wnZTXwREf1r6MF72++bE/fMk19LfVb8jN/qrUqAUXTc8gBAUxL5pgy8+oT/JnI2BkVrrLS4ilxEXP9Ahm+6GDUYXV4fBpqpZwdkzQ/5Gw=",
+        "x-amz-content-sha256": "UNSIGNED-PAYLOAD",
+    }
+
+
 def test_s3v4_rest_signer_forbidden(requests_mock: Mocker) -> None:
     requests_mock.post(
         f"{TEST_URI}/v1/aws/s3/sign",
